﻿using System;
using System.Collections.Generic;
using System.Configuration;
using System.Data;
using System.Linq;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Media;
using System.Windows.Shapes;
using CatanGame.Model;
using CatanGame.View;
using CatanGame.ViewModel;

namespace CatanGame
{
    /// <summary>
    /// Interaction logic for App.xaml
    /// </summary>
    public partial class App : Application
    {
        private MainWindow _mainWindow;
        private CatanViewModel _viewModel;
        private GameModel _model;

        App()
        {
            Startup += new StartupEventHandler(App_Startup);
        }

        #region Application event handlers

        private void App_Startup(object sender, StartupEventArgs e)
        {
            _mainWindow = new MainWindow();
            _model = new GameModel();
            _model.NewGame(new List<String> { "Geza", "Bela", "Anna" });
            _viewModel = new CatanViewModel(_model);
            _mainWindow.boardCanvas.ViewModel = _viewModel;
            _mainWindow.DataContext = _viewModel;
            _mainWindow.placeHouseButton.Click += settlementBuildButton_Clicked;
            _mainWindow.exitButton.Click += exitButton_clicked;

            _viewModel.UpgradeNode += ViewModel_UpgradeNode;

            _mainWindow.Show();
            
        }

        #endregion

        private void ViewModel_UpgradeNode(object sender, NodeCoordinates coords)
        {
            _model.UpgradeNode(coords, _model.CurrentPlayerId, true);
        }

        private void settlementBuildButton_Clicked(object sender, RoutedEventArgs e)
        {
            MessageBox.Show("OK", "OK");

        }
        private void exitButton_clicked(object sender, RoutedEventArgs e)
        {
            _mainWindow.Close();
        }
    }
}
