﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace CatanGame.Model
{
    public class GameModel
    {
        #region Events
        public event EventHandler<NodeCoordinates> NodeUpgraded;
        public event EventHandler GameRolled;
        #endregion

        public void NewGame(List<String> playerNames)
        {
            Board = new CatanBoard(playerNames);


        }

        public String GetPlayerName(int playerId)
        {
            return Board.Players[playerId].Name;
        }

        public void BuyCard(int playerId)
        {
            Board.BuyCard(Board.Players[playerId]);
        }

        public List<(NodeCoordinates, NodeCoordinates)> EnabledRoads(int playerId)
        {
            return Board.EnabledRoads(Board.Players[playerId]);
        }

        //public void PlaceRoad((int Row, int Column) coords, Player p)
        //{
        //    Board.PlaceRoad(coords, p);
        //}

        public void UpgradeNode(NodeCoordinates node, int playerId, bool start = false)
        {
            bool canPlace;
            if(Board.Nodes[node.R, node.Q, (int) node.Dir].Building.Type == HouseType.NoBuilding)
                canPlace = Board.PlaceSettlement(node, Board.Players[playerId], start);
            else
                canPlace = Board.UpgradeToCity(node, Board.Players[playerId]);
            
            if (canPlace)
                NodeUpgraded?.Invoke(this, node);
        }

        public void StepGame()
        {
            // 
        }

        public (int, int) Roll()
        {
            return Board.Roll();
        }

        private void SendResources(byte id)
        {
            Board.SendResources(id);
        }

        public CatanBoard Board { get; set; }

        public int CurrentPlayerId { get => Board.CurrentPlayerId; }
    }
}
